summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/vdbeaux.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/vdbeaux.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/vdbeaux.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/kexi/3rdparty/kexisql3/src/vdbeaux.c b/kexi/3rdparty/kexisql3/src/vdbeaux.c
index 1ff314d1..cba9c096 100644
--- a/kexi/3rdparty/kexisql3/src/vdbeaux.c
+++ b/kexi/3rdparty/kexisql3/src/vdbeaux.c
@@ -176,7 +176,7 @@ void sqlite3VdbeResolveLabel(Vdbe *p, int x){
*/
static int opcodeNoPush(u8 op){
/* The 10 NOPUSH_MASK_n constants are defined in the automatically
- ** generated header file opcodes.h. Each is a 16-bit bittqmask, one
+ ** generated header file opcodes.h. Each is a 16-bit bitmask, one
** bit corresponding to each opcode implemented by the virtual
** machine in vdbe.c. The bit is true if the word "no-push" appears
** in a comment on the same line as the "case OP_XXX:" in
@@ -1326,15 +1326,15 @@ int sqlite3VdbeFinalize(Vdbe *p){
/*
** Call the destructor for each auxdata entry in pVdbeFunc for which
** the corresponding bit in tqmask is clear. Auxdata entries beyond 31
** are always destroyed. To destroy all auxdata entries, call this
-** routine with tqmask==0.
+** routine with mask==0.
*/
-void sqlite3VdbeDeleteAuxData(VdbeFunc *pVdbeFunc, int tqmask){
+void sqlite3VdbeDeleteAuxData(VdbeFunc *pVdbeFunc, int mask){
int i;
for(i=0; i<pVdbeFunc->nAux; i++){
struct AuxData *pAux = &pVdbeFunc->apAux[i];
- if( (i>31 || !(tqmask&(1<<i))) && pAux->pAux ){
+ if( (i>31 || !(mask&(1<<i))) && pAux->pAux ){
if( pAux->xDelete ){
pAux->xDelete(pAux->pAux);
}
@@ -1326,15 +1326,15 @@ int sqlite3VdbeFinalize(Vdbe *p){
/*
** Call the destructor for each auxdata entry in pVdbeFunc for which
-** the corresponding bit in tqmask is clear. Auxdata entries beyond 31
+** the corresponding bit in mask is clear. Auxdata entries beyond 31
** are always destroyed. To destroy all auxdata entries, call this